-- Three Shell Game
-- Developed by Carlos Yanez

-- Hide Status Bar

display.setStatusBar(display.HiddenStatusBar)

-- Graphics

-- [Background]

local bg = display.newImage('bg.png')

-- [Title View]

local title
local playBtn
local creditsBtn
local titleView

-- [Credits]

local creditsView

-- [Bank Credits]

local bank
local bankText

-- [Shells]

local s1
local s2
local s3
local shells

-- [Ball]

local ball

-- [Button Bar]

local buttonBar

-- [Bet Button]

local betBtn

-- [Message Text]

local msg

-- [GameView]

local gameView

-- [Alert]

local alert

-- Variables

local moveSpeed = 600
local totalMoves = 5

-- Functions

local Main = {}
local startButtonListeners = {}
local showCredits = {}
local hideCredits = {}
local showGameView = {}
local placeBet = {}
local randomShellMove = {}
local checkMovesLeft = {}
local revealBall = {}
local alert = {}

-- Main Function

function Main()
	title = display.newImage('title.png', display.contentCenterX - 123, 40)
	playBtn = display.newImage('playBtn.png', display.contentCenterX - 25.5, display.contentCenterY - 10)
	creditsBtn = display.newImage('creditsBtn.png', display.contentCenterX - 40.5, display.contentCenterY + 45)
	titleView = display.newGroup(title, playBtn, creditsBtn)
	
	startButtonListeners('add')
end

function startButtonListeners(action)
	if(action == 'add') then
		playBtn:addEventListener('tap', showGameView)
		creditsBtn:addEventListener('tap', showCredits)
	else
		playBtn:removeEventListener('tap', showGameView)
		creditsBtn:removeEventListener('tap', showCredits)
	end
end

function showCredits:tap(e)
	playBtn.isVisible = false
	creditsBtn.isVisible = false
	creditsView = display.newImage('credits.png')
	transition.from(creditsView, {time = 300, x = -creditsView.width, onComplete = function() creditsView:addEventListener('tap', hideCredits) creditsView.x = creditsView.x - 0.5 end})
end

function hideCredits:tap(e)
	playBtn.isVisible = true
	creditsBtn.isVisible = true
	transition.to(creditsView, {time = 300, x = -creditsView.width, onComplete = function() creditsView:removeEventListener('tap', hideCredits) display.remove(creditsView) creditsView = nil end})
end

function showGameView:tap(e)
	transition.to(titleView, {time = 300, x = -titleView.height, onComplete = function() startButtonListeners('rmv') display.remove(titleView) titleView = nil end})
	
	-- [Bank Credits]
	
	bank = display.newText('5', 18, 5, native.systemFontBold, 14)
	bank:setTextColor(234, 170, 12)
	bankText = display.newImage('bankText.png', 7.5, 25)
	
	-- [Ball]
	
	ball = display.newImage('ball.png', 228, 142)
	
	-- [Shells]
	
	s1 = display.newImage('shell.png', 50, 114)
	s2 = display.newImage('shell.png', 195, 84)
	s2.name = 's2'
	s3 = display.newImage('shell.png', 340, 114)
	shells = display.newGroup(s1, s2, s3)
	
	-- [Button Bar]
	
	buttonBar = display.newImage('buttonBar.png', 0, 270)
	msg = display.newText('Click Bet to start', 1, 307, native.systemFont, 9)
	betBtn = display.newImage('betBtn.png', 223, 275)
	
	betBtn:addEventListener('tap', placeBet)
	
	gameView = display.newGroup(bank, bankText, ball, shells, buttonBar, msg, betBtn)
end

function placeBet:tap(e)	
	-- Place Bet
	
	bank.text = bank.text - 1;
	
	-- Remove Button Listener
	
	betBtn:removeEventListener('tap', placeBet)
	
	-- Change Msg
	
	msg.text = ''
	
	-- Reset Total Moves
	
	totalMoves = 5
	
	-- Hide Ball
	
	transition.to(s2, {time = moveSpeed, y = s2.y + 30, onComplete = randomShellMove})
end

function randomShellMove()
	local randm = math.floor(math.random() * 2) + 1
	
	local shell1 = shells[randm]
	local shell2
	
	if(shell1 ~= 3) then
		shell2 = shells[randm + 1]
	elseif(shell1 ~= 1) then
		shell2 = shells[randm - 1]
	end
	
	ball.isVisible = false
	
	totalMoves = totalMoves -1
	
	transition.to(shell1, {time = moveSpeed, x = shell2.x, y = shell2.y})
	transition.to(shell2, {time = moveSpeed, x = shell1.x, y = shell1.y, onComplete = checkMovesLeft})
end

function checkMovesLeft()
	if(totalMoves > 0) then
		randomShellMove()
	else
		s1:addEventListener('tap', revealBall)
		s2:addEventListener('tap', revealBall)
		s3:addEventListener('tap', revealBall)
		
		-- Change Msg
		
		msg.text = 'Click where the ball is'
		msg:setReferencePoint(display.TopLeftReferencePoint)
		msg.x = -20
	end
end

function revealBall:tap(e)
	-- Remove Shell Mouse Listeners
	
	s1:removeEventListener('tap', revealBall)
	s2:removeEventListener('tap', revealBall)
	s3:removeEventListener('tap', revealBall)
	
	-- Move Ball to correct position
	
	ball.x = s2.x + 75
	ball.y = s2.y + 150
	ball.isVisible = true
	
	-- Give credits if correct guess
	
	if(e.target.name == 's2') then
		bank.text = bank.text + 2
		
		-- Change Msg
		
		msg.text = 'Correct! Click Bet to play again'
		msg:setReferencePoint(display.TopLeftReferencePoint)
		msg.x = -20
	else
		msg.text = 'Wrong! Click Bet to play again'
		msg:setReferencePoint(display.TopLeftReferencePoint)
		msg.x = -20
	end
	
	-- Reveal Ball
	
	transition.to(s2, {time = moveSpeed, y = s2.y - 30})
	
	-- Add Bet button listener
	
	betBtn:addEventListener('tap', placeBet)
	
	-- Check for bank credits
	
	if(bank.text == '0') then
		betBtn:removeEventListener('tap', placeBet)
		
		alert()
	end
end

function alert()
	alert = display.newImage('alert.png')
	alert:setReferencePoint(display.CenterReferencePoint)
	alert.x = display.contentCenterX
	alert.y = display.contentCenterY
	transition.from(alert, {time = 300, xScale = 0.3, yScale = 0.3})
	
	msg.text = ''
	
	alert:addEventListener('tap', restart)
end

function restart()
	display.remove(gameView)
	gameView = nil
	display.remove(alert)
	alert = nil
	
	Main()
end

Main()